@@ -1,5 +1,5 @@
 package Cache::Bounded;
-$Cache::Bounded::VERSION='v1.06';
+$Cache::Bounded::VERSION='1.07';
 
 use strict;
 
@@ -154,14 +154,29 @@ not guarenteed.
 
 Use scalar data.
 
-=head1 AUTHORISHIP:
+=head1 BUGS AND SOURCE
 
-    Cache::Bounded v1.06 2012/03/04
+	Bug tracking for this module: https://rt.cpan.org/Dist/Display.html?Name=Cache-Bounded
 
-    (c) 2004-2012, Phillip Pollard <bennie@cpan.org>
-    Released under the Perl Artistic License
+	Source hosting: http://www.github.com/bennie/perl-Cache-Bounded
 
-    Derived from Cache::Sloppy v1.3 2004/03/02
+=head1 VERSION
+
+    Cache::Bounded v1.07 (2014/02/25)
+
+=head1 COPYRIGHT
+
+    (c) 2004-2014, Phillip Pollard <bennie@cpan.org>
+
+=head1 LICENSE
+
+This source code is released under the "Perl Artistic License 2.0," the text of 
+which is included in the LICENSE file of this distribution. It may also be 
+reviewed here: http://opensource.org/licenses/artistic-license-2.0
+
+=head1 AUTHORISHIP
+
+    Original derived from Cache::Sloppy v1.3 2004/03/02
     With permission granted from Health Market Science, Inc.
 
 =cut
